/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.mock;

import java.util.Collections;
import java.util.Map;

import org.ow2.petals.registry.client.api.TopologyService;
import org.ow2.petals.registry.client.api.exception.UnexistingTopologyException;
import org.ow2.petals.topology.generated.Topology;

/**
 * A mock of the {@link TopologyService}.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class TopologyServiceMock implements TopologyService {

    /**
     * The map in which topologies will be registered
     */
    private Map<String, Topology> topologyMap;

    public TopologyServiceMock(final Map<String, Topology> topologyMap) {
        this.topologyMap = topologyMap;
    }

    @Override
    public Map<String, Topology> getTopologies() {
        return Collections.unmodifiableMap(this.topologyMap);
    }

    @Override
    public Topology getTopology(final String topologyId) {
        return this.topologyMap.get(topologyId);
    }

    @Override
    public void clean(final String domain, final String subDomain) throws UnexistingTopologyException {
        final String topologyId = this.getTopologyId(domain, subDomain);
        if (this.topologyMap.containsKey(topologyId)) {
            this.topologyMap.remove(topologyId);
        } else {
            throw new UnexistingTopologyException(topologyId);
        }
    }

    private String getTopologyId(final String domain, final String subDomain) {
        return domain + "-" + subDomain;
    }

}
